@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # @XZGUtil    : 2020-12-23 21:28
-# @Site    : 
+# @Site    :
 # @File    : timeUtil.py
 # @Software: PyCharm
 """
@@ -32,15 +32,36 @@ def datetime_toString_detail(dt: datetime) -> str:
     """
     return dt.strftime("%Y-%m-%d %H:%M:%S")
 
+def get_now_date():
+    """
+    获取今日日期字符串
+    :return:  '2020-01-01'
+    """
+    return datetime.datetime.now().strftime("%Y-%m-%d")
+
+def get_now_time():
+    """
+    获取现在时间字符串
+    :return:  '2020-01-01 15:29:08'
+    """
+    return datetime.datetime.now().strftime("%Y-%m-%d  %H:%M:%S")
 
 def string_toDatetime(string: str) -> datetime:
     """
-    把字符串转成datetime
+    把字符串转成datetime  精确到日
     :param string: '2020-01-01'
     :return:
     """
     return datetime.datetime.strptime(string, "%Y-%m-%d")
 
+def detail_string_toDatetime(string: str) -> datetime:
+    """
+    把字符串转成datetime 精确到秒
+    :param string: '2020-01-01'
+    :return:
+    """
+    return datetime.datetime.strptime(string, "%Y-%m-%d  %H:%M:%S")
+
 
 def string_toTimestamp(strTime: str) -> int:
     """
@@ -79,6 +100,7 @@ def datetime_toTimestamp(dateTime):
 
 
 def string_totime_detail(str_p):
+    """时间字符串转换成时间类型"""
     """2019-01-30 15:29:08"""
     dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d %H:%M:%S')
     return dateTime_p
@@ -142,9 +164,21 @@ def dateTime_Add(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     :param minutes:1
     :return:<class 'datetime.datetime'> 2020-01-02 01:01:01
     """
-    date1 = string_toDatetime(dateStr)
+    date1 = detail_string_toDatetime(dateStr)
     return date1 + datetime.timedelta(days=days, hours=hours, minutes=minutes)
 
+def dateTime_Subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
+    """
+    指定日期减去 一个时间段，天，小时，或分钟之后的日期
+    :param dateStr:'2020-01-01'
+    :param days:1
+    :param hours:1
+    :param minutes:1
+    :return:<class 'datetime.datetime'> 2020-01-02 01:01:01
+    """
+    date1 = detail_string_toDatetime(dateStr)
+    return date1 - datetime.timedelta(days=days, hours=hours, minutes=minutes)
+
 
 def format_nowtime_millisecond() -> int:
     """
@@ -282,4 +316,4 @@ def get_taobao_time():
 if __name__ == '__main__':
     # month_begin_day = month_datelist('2020-01')
     # print(getdate(1))
-    print(substract_Time_detail('2021-05-01 09:00:00', '2021-05-01 10:05:00'))
+    print(dateTime_Subtraction('2021-05-01 09:00:00', hours=3))
